mod sensors;
mod comm;

use comm::{Channel, Message};
use std::io;
use std::sync::mpsc;
use std::thread;

fn main() {
    let (tx, rx) = mpsc::channel::<Message>();
    make_thread(&tx, stdin);
    make_thread(&tx, sensors::sensors);

    let mut data;

    loop {
        let msg = rx.recv().unwrap();
        match msg {
            Message { text, .. } => data = text,
        }
        println!("%{{r}}{}", data);
    }
}

fn make_thread(tx: &Channel, func: fn(&Channel) -> ()) {
    let thread_tx = tx.clone();
    thread::spawn(move || {
        func(&thread_tx);
    });
}

fn stdin(tx: &Channel) {
    let mut line = String::new();
    loop {
        io::stdin().read_line(&mut line).ok().expect("Failed to read line");
    }
}

